EXSWHTEC-7 - Implement tests for error handling APIs (#2883)
- Validate that hipGetErrorName returns a non empty string for all error enumerators - Validate that hipGetErrorString returns a non empty string for all error enumerators - Negative parameter test for hipGetErrorName and hipGetErrorString - Validate expected behaviour of hipGetLastError and hipPeekAtLastError - Multithreaded tests for hipGetLastError and hipPeekAtLastError - Remove threaded_zig_zag_test. - Validate error string for invalid error enumerator - Remove empty lines from HipGetLastErrorThreadedTest and HipPeekAtLastErrorTest. - Removed unnecessary check in hipGetErrorString negative test.
This commit is contained in:
@@ -32,6 +32,7 @@ add_subdirectory(streamperthread)
|
|||||||
add_subdirectory(kernel)
|
add_subdirectory(kernel)
|
||||||
add_subdirectory(multiThread)
|
add_subdirectory(multiThread)
|
||||||
add_subdirectory(compiler)
|
add_subdirectory(compiler)
|
||||||
|
add_subdirectory(errorHandling)
|
||||||
if(HIP_PLATFORM STREQUAL "amd")
|
if(HIP_PLATFORM STREQUAL "amd")
|
||||||
add_subdirectory(clock)
|
add_subdirectory(clock)
|
||||||
endif()
|
endif()
|
||||||
|
|||||||
@@ -0,0 +1,12 @@
|
|||||||
|
# Common Tests - Test independent of all platforms
|
||||||
|
set(TEST_SRC
|
||||||
|
hipGetErrorName.cc
|
||||||
|
hipGetErrorString.cc
|
||||||
|
hipGetLastError.cc
|
||||||
|
hipPeekAtLastError.cc
|
||||||
|
)
|
||||||
|
|
||||||
|
hip_add_exe_to_target(NAME ErrorHandlingTest
|
||||||
|
TEST_SRC ${TEST_SRC}
|
||||||
|
TEST_TARGET_NAME build_tests
|
||||||
|
COMPILE_OPTIONS -std=c++14)
|
||||||
@@ -0,0 +1,99 @@
|
|||||||
|
/*
|
||||||
|
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
|
||||||
|
|
||||||
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||||
|
of this software and associated documentation files (the "Software"), to deal
|
||||||
|
in the Software without restriction, including without limitation the rights
|
||||||
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||||
|
copies of the Software, and to permit persons to whom the Software is
|
||||||
|
furnished to do so, subject to the following conditions:
|
||||||
|
|
||||||
|
The above copyright notice and this permission notice shall be included in
|
||||||
|
all copies or substantial portions of the Software.
|
||||||
|
|
||||||
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
||||||
|
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||||
|
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||||
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
||||||
|
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||||
|
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||||
|
THE SOFTWARE.
|
||||||
|
*/
|
||||||
|
|
||||||
|
#pragma once
|
||||||
|
|
||||||
|
#include <hip/hip_runtime_api.h>
|
||||||
|
|
||||||
|
constexpr hipError_t kErrorEnumerators[] = {hipSuccess,
|
||||||
|
hipErrorInvalidValue,
|
||||||
|
hipErrorOutOfMemory,
|
||||||
|
hipErrorNotInitialized,
|
||||||
|
hipErrorDeinitialized,
|
||||||
|
hipErrorProfilerDisabled,
|
||||||
|
hipErrorProfilerNotInitialized,
|
||||||
|
hipErrorProfilerAlreadyStarted,
|
||||||
|
hipErrorProfilerAlreadyStopped,
|
||||||
|
hipErrorInvalidConfiguration,
|
||||||
|
hipErrorInvalidPitchValue,
|
||||||
|
hipErrorInvalidSymbol,
|
||||||
|
hipErrorInvalidDevicePointer,
|
||||||
|
hipErrorInvalidMemcpyDirection,
|
||||||
|
hipErrorInsufficientDriver,
|
||||||
|
hipErrorMissingConfiguration,
|
||||||
|
hipErrorPriorLaunchFailure,
|
||||||
|
hipErrorInvalidDeviceFunction,
|
||||||
|
hipErrorNoDevice,
|
||||||
|
hipErrorInvalidDevice,
|
||||||
|
hipErrorInvalidImage,
|
||||||
|
hipErrorInvalidContext,
|
||||||
|
hipErrorContextAlreadyCurrent,
|
||||||
|
hipErrorMapFailed,
|
||||||
|
hipErrorUnmapFailed,
|
||||||
|
hipErrorArrayIsMapped,
|
||||||
|
hipErrorAlreadyMapped,
|
||||||
|
hipErrorNoBinaryForGpu,
|
||||||
|
hipErrorAlreadyAcquired,
|
||||||
|
hipErrorNotMapped,
|
||||||
|
hipErrorNotMappedAsArray,
|
||||||
|
hipErrorNotMappedAsPointer,
|
||||||
|
hipErrorECCNotCorrectable,
|
||||||
|
hipErrorUnsupportedLimit,
|
||||||
|
hipErrorContextAlreadyInUse,
|
||||||
|
hipErrorPeerAccessUnsupported,
|
||||||
|
hipErrorInvalidKernelFile,
|
||||||
|
hipErrorInvalidGraphicsContext,
|
||||||
|
hipErrorInvalidSource,
|
||||||
|
hipErrorFileNotFound,
|
||||||
|
hipErrorSharedObjectSymbolNotFound,
|
||||||
|
hipErrorSharedObjectInitFailed,
|
||||||
|
hipErrorOperatingSystem,
|
||||||
|
hipErrorInvalidHandle,
|
||||||
|
hipErrorIllegalState,
|
||||||
|
hipErrorNotFound,
|
||||||
|
hipErrorNotReady,
|
||||||
|
hipErrorIllegalAddress,
|
||||||
|
hipErrorLaunchOutOfResources,
|
||||||
|
hipErrorLaunchTimeOut,
|
||||||
|
hipErrorPeerAccessAlreadyEnabled,
|
||||||
|
hipErrorPeerAccessNotEnabled,
|
||||||
|
hipErrorSetOnActiveProcess,
|
||||||
|
hipErrorContextIsDestroyed,
|
||||||
|
hipErrorAssert,
|
||||||
|
hipErrorHostMemoryAlreadyRegistered,
|
||||||
|
hipErrorHostMemoryNotRegistered,
|
||||||
|
hipErrorLaunchFailure,
|
||||||
|
hipErrorCooperativeLaunchTooLarge,
|
||||||
|
hipErrorNotSupported,
|
||||||
|
hipErrorStreamCaptureUnsupported,
|
||||||
|
hipErrorStreamCaptureInvalidated,
|
||||||
|
hipErrorStreamCaptureMerge,
|
||||||
|
hipErrorStreamCaptureUnmatched,
|
||||||
|
hipErrorStreamCaptureUnjoined,
|
||||||
|
hipErrorStreamCaptureIsolation,
|
||||||
|
hipErrorStreamCaptureImplicit,
|
||||||
|
hipErrorCapturedEvent,
|
||||||
|
hipErrorStreamCaptureWrongThread,
|
||||||
|
hipErrorGraphExecUpdateFailure,
|
||||||
|
hipErrorUnknown,
|
||||||
|
hipErrorRuntimeMemory,
|
||||||
|
hipErrorRuntimeOther};
|
||||||
@@ -0,0 +1,47 @@
|
|||||||
|
/*
|
||||||
|
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
|
||||||
|
|
||||||
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||||
|
of this software and associated documentation files (the "Software"), to deal
|
||||||
|
in the Software without restriction, including without limitation the rights
|
||||||
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||||
|
copies of the Software, and to permit persons to whom the Software is
|
||||||
|
furnished to do so, subject to the following conditions:
|
||||||
|
|
||||||
|
The above copyright notice and this permission notice shall be included in
|
||||||
|
all copies or substantial portions of the Software.
|
||||||
|
|
||||||
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
||||||
|
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||||
|
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||||
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
||||||
|
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||||
|
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||||
|
THE SOFTWARE.
|
||||||
|
*/
|
||||||
|
|
||||||
|
|
||||||
|
#include "errorEnumerators.h"
|
||||||
|
#include <hip_test_common.hh>
|
||||||
|
#include <hip/hip_runtime_api.h>
|
||||||
|
|
||||||
|
TEST_CASE("Unit_hipGetErrorName_Positive_Basic") {
|
||||||
|
const char* error_string = nullptr;
|
||||||
|
const auto enumerator =
|
||||||
|
GENERATE(from_range(std::begin(kErrorEnumerators), std::end(kErrorEnumerators)));
|
||||||
|
|
||||||
|
error_string = hipGetErrorName(enumerator);
|
||||||
|
|
||||||
|
REQUIRE(error_string != nullptr);
|
||||||
|
REQUIRE(strlen(error_string) > 0);
|
||||||
|
}
|
||||||
|
|
||||||
|
TEST_CASE("Unit_hipGetErrorName_Negative_Parameters") {
|
||||||
|
const char* error_string = hipGetErrorName(static_cast<hipError_t>(-1));
|
||||||
|
REQUIRE(error_string != nullptr);
|
||||||
|
#if HT_NVIDIA
|
||||||
|
REQUIRE_THAT(error_string, Catch::Equals("cudaErrorUnknown"));
|
||||||
|
#elif HT_AMD
|
||||||
|
REQUIRE_THAT(error_string, Catch::Equals("hipErrorUnknown"));
|
||||||
|
#endif
|
||||||
|
}
|
||||||
@@ -0,0 +1,41 @@
|
|||||||
|
/*
|
||||||
|
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
|
||||||
|
|
||||||
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||||
|
of this software and associated documentation files (the "Software"), to deal
|
||||||
|
in the Software without restriction, including without limitation the rights
|
||||||
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||||
|
copies of the Software, and to permit persons to whom the Software is
|
||||||
|
furnished to do so, subject to the following conditions:
|
||||||
|
|
||||||
|
The above copyright notice and this permission notice shall be included in
|
||||||
|
all copies or substantial portions of the Software.
|
||||||
|
|
||||||
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
||||||
|
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||||
|
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||||
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
||||||
|
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||||
|
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||||
|
THE SOFTWARE.
|
||||||
|
*/
|
||||||
|
|
||||||
|
#include "errorEnumerators.h"
|
||||||
|
#include <hip_test_common.hh>
|
||||||
|
#include <hip/hip_runtime_api.h>
|
||||||
|
|
||||||
|
TEST_CASE("Unit_hipGetErrorString_Positive_Basic") {
|
||||||
|
const char* error_string = nullptr;
|
||||||
|
const auto enumerator =
|
||||||
|
GENERATE(from_range(std::begin(kErrorEnumerators), std::end(kErrorEnumerators)));
|
||||||
|
|
||||||
|
error_string = hipGetErrorString(enumerator);
|
||||||
|
|
||||||
|
REQUIRE(error_string != nullptr);
|
||||||
|
REQUIRE(strlen(error_string) > 0);
|
||||||
|
}
|
||||||
|
|
||||||
|
TEST_CASE("Unit_hipGetErrorString_Negative_Parameters") {
|
||||||
|
const char* error_string = hipGetErrorString(static_cast<hipError_t>(-1));
|
||||||
|
REQUIRE(error_string != nullptr);
|
||||||
|
}
|
||||||
@@ -0,0 +1,44 @@
|
|||||||
|
/*
|
||||||
|
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
|
||||||
|
|
||||||
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||||
|
of this software and associated documentation files (the "Software"), to deal
|
||||||
|
in the Software without restriction, including without limitation the rights
|
||||||
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||||
|
copies of the Software, and to permit persons to whom the Software is
|
||||||
|
furnished to do so, subject to the following conditions:
|
||||||
|
|
||||||
|
The above copyright notice and this permission notice shall be included in
|
||||||
|
all copies or substantial portions of the Software.
|
||||||
|
|
||||||
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
||||||
|
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||||
|
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||||
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
||||||
|
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||||
|
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||||
|
THE SOFTWARE.
|
||||||
|
*/
|
||||||
|
|
||||||
|
#include <hip_test_common.hh>
|
||||||
|
#include <hip/hip_runtime_api.h>
|
||||||
|
#include <threaded_zig_zag_test.hh>
|
||||||
|
|
||||||
|
TEST_CASE("Unit_hipGetLastError_Positive_Basic") {
|
||||||
|
HIP_CHECK(hipGetLastError());
|
||||||
|
HIP_CHECK_ERROR(hipMalloc(nullptr, 1), hipErrorInvalidValue);
|
||||||
|
HIP_CHECK_ERROR(hipGetLastError(), hipErrorInvalidValue);
|
||||||
|
HIP_CHECK(hipGetLastError());
|
||||||
|
}
|
||||||
|
|
||||||
|
TEST_CASE("Unit_hipGetLastError_Positive_Threaded") {
|
||||||
|
class HipGetLastErrorThreadedTest : public ThreadedZigZagTest<HipGetLastErrorThreadedTest> {
|
||||||
|
public:
|
||||||
|
void TestPart2() { REQUIRE_THREAD(hipMalloc(nullptr, 1) == hipErrorInvalidValue); }
|
||||||
|
void TestPart3() { HIP_CHECK(hipGetLastError()); }
|
||||||
|
void TestPart4() { REQUIRE_THREAD(hipGetLastError() == hipErrorInvalidValue); }
|
||||||
|
};
|
||||||
|
|
||||||
|
HipGetLastErrorThreadedTest test;
|
||||||
|
test.run();
|
||||||
|
}
|
||||||
@@ -0,0 +1,48 @@
|
|||||||
|
/*
|
||||||
|
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
|
||||||
|
|
||||||
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||||
|
of this software and associated documentation files (the "Software"), to deal
|
||||||
|
in the Software without restriction, including without limitation the rights
|
||||||
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||||
|
copies of the Software, and to permit persons to whom the Software is
|
||||||
|
furnished to do so, subject to the following conditions:
|
||||||
|
|
||||||
|
The above copyright notice and this permission notice shall be included in
|
||||||
|
all copies or substantial portions of the Software.
|
||||||
|
|
||||||
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
||||||
|
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||||
|
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||||
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
||||||
|
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||||
|
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||||
|
THE SOFTWARE.
|
||||||
|
*/
|
||||||
|
|
||||||
|
#include <hip_test_common.hh>
|
||||||
|
#include <hip/hip_runtime_api.h>
|
||||||
|
#include <threaded_zig_zag_test.hh>
|
||||||
|
|
||||||
|
TEST_CASE("Unit_hipPeekAtLastError_Positive_Basic") {
|
||||||
|
HIP_CHECK(hipPeekAtLastError());
|
||||||
|
HIP_CHECK_ERROR(hipMalloc(nullptr, 1), hipErrorInvalidValue);
|
||||||
|
HIP_CHECK_ERROR(hipPeekAtLastError(), hipErrorInvalidValue);
|
||||||
|
HIP_CHECK_ERROR(hipGetLastError(), hipErrorInvalidValue);
|
||||||
|
HIP_CHECK(hipPeekAtLastError());
|
||||||
|
}
|
||||||
|
|
||||||
|
TEST_CASE("Unit_hipPeekAtLastError_Positive_Threaded") {
|
||||||
|
class HipPeekAtLastErrorTest : public ThreadedZigZagTest<HipPeekAtLastErrorTest> {
|
||||||
|
public:
|
||||||
|
void TestPart2() { REQUIRE_THREAD(hipMalloc(nullptr, 1) == hipErrorInvalidValue); }
|
||||||
|
void TestPart3() {
|
||||||
|
HIP_CHECK(hipPeekAtLastError());
|
||||||
|
HIP_CHECK(hipGetLastError());
|
||||||
|
}
|
||||||
|
void TestPart4() { REQUIRE_THREAD(hipPeekAtLastError() == hipErrorInvalidValue); }
|
||||||
|
};
|
||||||
|
|
||||||
|
HipPeekAtLastErrorTest test;
|
||||||
|
test.run();
|
||||||
|
}
|
||||||
مرجع در شماره جدید
Block a user